@@ -12,15 +12,14 @@ extern void F77_NAME(binsrt)(double *, double *, double *, int *, int *,
 extern void F77_NAME(intri)(double *, double *, double *, double *, int *,
                             int *);
 extern void F77_NAME(master)(double *, double *, double *, int *, int *,
-                             int *, int *, double *, double *, double *,
-                             double *, int *, double *, double *, int *,
-                             double *, int *);
+                             int *, int *, double *, double *, int *,
+                             double *, double *, int *, double *, int *);
 extern void F77_NAME(mnnd)(double *, double *, int *, double *, double *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"binsrt", (DL_FUNC) &F77_NAME(binsrt), 10},
     {"intri",  (DL_FUNC) &F77_NAME(intri),   6},
-    {"master", (DL_FUNC) &F77_NAME(master), 17},
+    {"master", (DL_FUNC) &F77_NAME(master), 15},
     {"mnnd",   (DL_FUNC) &F77_NAME(mnnd),    5},
     {NULL, NULL, 0}
 };
